@@ -29,6 +29,14 @@
 #include "gsm_color_button.h"
 
 
+void LoadGraph::clear_background()
+{
+	if (this->background) {
+		g_object_unref(this->background);
+		this->background = NULL;
+	}
+}
+
 
 unsigned LoadGraph::num_bars() const
 {
@@ -59,6 +67,7 @@ unsigned LoadGraph::num_bars() const
 
 #define FRAME_WIDTH 4
 void draw_background(LoadGraph *g) {
+	GtkAllocation allocation;
 	double dash[2] = { 1.0, 2.0 };
 	cairo_t *cr;
 	guint i;
@@ -72,9 +81,10 @@ void draw_background(LoadGraph *g) {
 	g->graph_delx = (g->draw_width - 2.0 - g->rmargin - g->indent) / (LoadGraph::NUM_POINTS - 3);
 	g->graph_buffer_offset = (int) (1.5 * g->graph_delx) + FRAME_WIDTH ;
 
-	g->background = gdk_pixmap_new (GDK_DRAWABLE (g->disp->window),
-					g->disp->allocation.width,
-					g->disp->allocation.height,
+	gtk_widget_get_allocation (g->disp, &allocation);
+	g->background = gdk_pixmap_new (GDK_DRAWABLE (gtk_widget_get_window (g->disp)),
+					allocation.width,
+					allocation.height,
 					-1);
 	cr = gdk_cairo_create (g->background);
 	
@@ -110,7 +120,7 @@ void draw_background(LoadGraph *g) {
 		if (g->type == LOAD_GRAPH_NET) {
 			// operation orders matters so it's 0 if i == num_bars
 			unsigned rate = g->net.max - (i * g->net.max / num_bars);
-			const std::string caption(procman::format_rate(rate, g->net.max));
+			const std::string caption(procman::format_network_rate(rate, g->net.max));
 			cairo_text_extents (cr, caption.c_str(), &extents);
 			cairo_move_to (cr, g->indent - extents.width + 20, y);
 			cairo_show_text (cr, caption.c_str());
@@ -172,17 +182,17 @@ load_graph_configure (GtkWidget *widget,
 		      GdkEventConfigure *event,
 		      gpointer data_ptr)
 {
+	GtkAllocation allocation;
 	LoadGraph * const g = static_cast<LoadGraph*>(data_ptr);
-	g->draw_width = widget->allocation.width - 2 * FRAME_WIDTH;
-	g->draw_height = widget->allocation.height - 2 * FRAME_WIDTH;
 
-	if (g->background) {
-		g_object_unref (g->background);
-		g->background = NULL;
-	}
+	gtk_widget_get_allocation (widget, &allocation);
+	g->draw_width = allocation.width - 2 * FRAME_WIDTH;
+	g->draw_height = allocation.height - 2 * FRAME_WIDTH;
+
+	g->clear_background();
 
 	if (g->gc == NULL) {
-		g->gc = gdk_gc_new (GDK_DRAWABLE (widget->window));
+		g->gc = gdk_gc_new (GDK_DRAWABLE (gtk_widget_get_window (widget)));
 	}
 
 	load_graph_draw (g);
@@ -196,6 +206,8 @@ load_graph_expose (GtkWidget *widget,
 		   gpointer data_ptr)
 {
 	LoadGraph * const g = static_cast<LoadGraph*>(data_ptr);
+	GtkAllocation allocation;
+	GdkWindow *window;
 
 	guint i, j;
 	gdouble sample_width, x_offset;
@@ -203,12 +215,15 @@ load_graph_expose (GtkWidget *widget,
 	if (g->background == NULL) {
 		draw_background(g);
 	}
-	gdk_draw_drawable (g->disp->window,
+
+	window = gtk_widget_get_window (g->disp);
+	gtk_widget_get_allocation (g->disp, &allocation);
+	gdk_draw_drawable (window,
 			   g->gc,
 			   g->background,
 			   0, 0, 0, 0, 
-			   g->disp->allocation.width, 
-			   g->disp->allocation.height);
+			   allocation.width,
+			   allocation.height);
 
 	/* Number of pixels wide for one graph point */
 	sample_width = (float)(g->draw_width - g->rmargin - g->indent) / (float)LoadGraph::NUM_POINTS;
@@ -221,7 +236,7 @@ load_graph_expose (GtkWidget *widget,
 	/* draw the graph */
 	cairo_t* cr;
 
-	cr = gdk_cairo_create (g->disp->window);
+	cr = gdk_cairo_create (window);
 
 	cairo_set_line_width (cr, 1);
 	cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
@@ -383,45 +398,59 @@ net_scale (LoadGraph *g, unsigned din, unsigned dout)
 
 	const unsigned bak_max(new_max);
 
-	// round up to get some extra space
-	new_max = 11U * new_max / 10U;
-	// make sure max is not 0 to avoid / 0
-	// default to 1 KiB
-	new_max = std::max(new_max, 1024U);
+	if (ProcData::get_instance()->config.network_in_bits) {
+	  // TODO: fix logic to give a nice scale with bits
 
-	// decompose new_max = coef10 * 2**(base10 * 10)
-	// where coef10 and base10 are integers and coef10 < 2**10
-	//
-	// e.g: ceil(100.5 KiB) = 101 KiB = 101 * 2**(1 * 10)
-	//      where base10 = 1, coef10 = 101, pow2 = 16
+	  // round up to get some extra space
+	  // yes, it can overflow
+	  new_max = 1.1 * new_max;
+	  // make sure max is not 0 to avoid / 0
+	  // default to 125 bytes == 1kbit
+	  new_max = std::max(new_max, 125U);
 
-	unsigned pow2 = std::floor(log2(new_max));
-	unsigned base10 = pow2 / 10;
-	unsigned coef10 = std::ceil(new_max / double(1UL << (base10 * 10)));
-	g_assert(new_max <= (coef10 * (1UL << (base10 * 10))));
+	} else {
+	  // round up to get some extra space
+	  // yes, it can overflow
+	  new_max = 1.1 * new_max;
+	  // make sure max is not 0 to avoid / 0
+	  // default to 1 KiB
+	  new_max = std::max(new_max, 1024U);
 
-	// then decompose coef10 = x * 10**factor10
-	// where factor10 is integer and x < 10
-	// so we new_max has only 1 significant digit
+	  // decompose new_max = coef10 * 2**(base10 * 10)
+	  // where coef10 and base10 are integers and coef10 < 2**10
+	  //
+	  // e.g: ceil(100.5 KiB) = 101 KiB = 101 * 2**(1 * 10)
+	  //      where base10 = 1, coef10 = 101, pow2 = 16
 
-	unsigned factor10 = std::pow(10.0, std::floor(std::log10(coef10)));
-	coef10 = std::ceil(coef10 / double(factor10)) * factor10;
+	  unsigned pow2 = std::floor(log2(new_max));
+	  unsigned base10 = pow2 / 10;
+	  unsigned coef10 = std::ceil(new_max / double(1UL << (base10 * 10)));
+	  g_assert(new_max <= (coef10 * (1UL << (base10 * 10))));
 
-	// then make coef10 divisible by num_bars
-	if (coef10 % g->num_bars() != 0)
-		coef10 = coef10 + (g->num_bars() - coef10 % g->num_bars());
-	g_assert(coef10 % g->num_bars() == 0);
+	  // then decompose coef10 = x * 10**factor10
+	  // where factor10 is integer and x < 10
+	  // so we new_max has only 1 significant digit
 
-	new_max = coef10 * (1UL << (base10 * 10));
-	procman_debug("bak %u new_max %u pow2 %u coef10 %u", bak_max, new_max, pow2, coef10);
-	g_assert(bak_max <= new_max);
+	  unsigned factor10 = std::pow(10.0, std::floor(std::log10(coef10)));
+	  coef10 = std::ceil(coef10 / double(factor10)) * factor10;
 
-	if (new_max == g->net.max)
-		return;
+	  // then make coef10 divisible by num_bars
+	  if (coef10 % g->num_bars() != 0)
+	    coef10 = coef10 + (g->num_bars() - coef10 % g->num_bars());
+	  g_assert(coef10 % g->num_bars() == 0);
 
-	// if max has decreased but not so much, don't do anything
-	// to avoid rescaling
-	if ((8U * g->net.max / 10U) < new_max && new_max < g->net.max)
+	  new_max = coef10 * (1UL << (base10 * 10));
+	  procman_debug("bak %u new_max %u pow2 %u coef10 %u", bak_max, new_max, pow2, coef10);
+	}
+
+	if (bak_max > new_max) {
+	  procman_debug("overflow detected: bak=%u new=%u", bak_max, new_max);
+	  new_max = bak_max;
+	}
+
+	// if max is the same or has decreased but not so much, don't
+	// do anything to avoid rescaling
+	if ((0.8 * g->net.max) < new_max && new_max <= g->net.max)
 		return;
 
 	const float scale = 1.0f * g->net.max / new_max;
@@ -433,15 +462,12 @@ net_scale (LoadGraph *g, unsigned din, unsigned dout)
 		}
 	}
 
-	procman_debug("dmax = %u max = %u new_max = %u", dmax, g->net.max, new_max);
+	procman_debug("rescale dmax = %u max = %u new_max = %u", dmax, g->net.max, new_max);
 
 	g->net.max = new_max;
 
 	// force the graph background to be redrawn now that scale has changed
-	if (g->background) {
-		g_object_unref (g->background);
-		g->background = NULL;
-	}
+	g->clear_background();
 }
 
 static void
@@ -453,7 +479,6 @@ get_net (LoadGraph *g)
 	guint64 in = 0, out = 0;
 	GTimeVal time;
 	unsigned din, dout;
-	gchar *text1;
 
 	ifnames = glibtop_get_netlist(&netlist);
 
@@ -509,17 +534,11 @@ get_net (LoadGraph *g)
 	net_scale(g, din, dout);
 
 
-	gtk_label_set_text (GTK_LABEL (g->labels.net_in), procman::format_rate(din).c_str());
+	gtk_label_set_text (GTK_LABEL (g->labels.net_in), procman::format_network_rate(din).c_str());
+	gtk_label_set_text (GTK_LABEL (g->labels.net_in_total), procman::format_network(in).c_str());
 
-	text1 = procman::format_size (in);
-	gtk_label_set_text (GTK_LABEL (g->labels.net_in_total), text1);
-	g_free (text1);
-
-	gtk_label_set_text (GTK_LABEL (g->labels.net_out), procman::format_rate(dout).c_str());
-
-	text1 = procman::format_size (out);
-	gtk_label_set_text (GTK_LABEL (g->labels.net_out_total), text1);
-	g_free (text1);
+	gtk_label_set_text (GTK_LABEL (g->labels.net_out), procman::format_network_rate(dout).c_str());
+	gtk_label_set_text (GTK_LABEL (g->labels.net_out_total), procman::format_network(out).c_str());
 }
 
 
@@ -567,8 +586,7 @@ LoadGraph::~LoadGraph()
   if (this->timer_index)
     g_source_remove(this->timer_index);
 
-  if (this->background)
-    g_object_unref (this->background);
+  this->clear_background();
 }
 
 
@@ -740,10 +758,7 @@ load_graph_change_speed (LoadGraph *g,
 						g);
 	}
 
-	if (g->background != NULL) {
-		g_object_unref(g->background);
-		g->background = NULL;
-	}
+	g->clear_background();
 }
 
 
