@@ -28,17 +28,16 @@
 #include <glibtop/cpu.h>
 
 #include <time.h>
+#include <sys/types.h>
 
 #include <map>
+#include <string>
 
-typedef struct _ProcConfig ProcConfig;
 struct ProcInfo;
 struct ProcData;
+struct LoadGraph;
 
 #include "smooth_refresh.h"
-
-#include "load-graph.h"
-
 #include "prettytable.h"
 
 enum
@@ -53,6 +52,13 @@ static const unsigned MIN_UPDATE_INTERVAL =   1 * 1000;
 static const unsigned MAX_UPDATE_INTERVAL = 100 * 1000;
 
 
+namespace procman
+{
+	extern const std::string SHOW_SYSTEM_TAB_CMD;
+}
+
+
+
 enum ProcmanTab
 {
 	PROCMAN_TAB_SYSINFO,
@@ -62,7 +68,7 @@ enum ProcmanTab
 };
 
 
-struct _ProcConfig
+struct ProcConfig
 {
 	gint		width;
 	gint		height;
@@ -83,6 +89,7 @@ struct _ProcConfig
 	GdkColor	frame_color;
 	gint 		num_cpus;
 	bool solaris_mode;
+	bool network_in_bits;
 };
 
 
@@ -90,12 +97,12 @@ struct _ProcConfig
 struct MutableProcInfo
 {
   MutableProcInfo()
-    : user(0),
-      status(0)
+    : status(0)
   { }
 
-  // allocated with g_string_chunk, don't free it !
-  gchar* user;
+  std::string user;
+
+  gchar wchan[40];
 
   // all these members are filled with libgtop which uses
   // guint64 (to have fixed size data) but we don't need more
@@ -123,6 +130,11 @@ class ProcInfo
 {
 	/* undefined */ ProcInfo& operator=(const ProcInfo&);
 	/* undefined */ ProcInfo(const ProcInfo&);
+
+	typedef std::map<guint, std::string> UserMap;
+	/* cached username */
+	static UserMap users;
+
  public:
 
 	// TODO: use a set instead
@@ -143,6 +155,7 @@ class ProcInfo
 	~ProcInfo();
 	// adds one more ref to icon
 	void set_icon(Glib::RefPtr<Gdk::Pixbuf> icon);
+	void set_user(guint uid);
 
 	GtkTreeIter	node;
 	Glib::RefPtr<Gdk::Pixbuf> pixbuf;
@@ -197,10 +210,6 @@ struct ProcData
 	GtkWidget	*app;
 	GtkUIManager	*menu;
 
-
-	/* cached username */
-	GStringChunk	*users;
-
 	unsigned	frequency;
 
 	SmoothRefresh  *smooth_refresh;
